==> haskell-bower-json-1.0.0.1-118-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bower-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bower-json
version: 1.0.0.1
id: bower-json-1.0.0.1-EoWydgDtL842E9jXtX81Ro
key: bower-json-1.0.0.1-EoWydgDtL842E9jXtX81Ro
license: MIT
maintainer: harry@garrood.me
author: Harry Garrood
homepage: https://github.com/hdgarrood/bower-json
synopsis: Read bower.json from Haskell
description:
    Bower is a package manager for the web (see <http://bower.io>).
    This package provides a data type and ToJSON/FromJSON instances for Bower'\''s
    package manifest file, bower.json.
category: Web
abi: 66259d7ed22233eb7fb907135d3dd452
exposed: True
exposed-modules:
    Web.Bower.PackageMeta
hidden-modules: Web.Bower.PackageMeta.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/bower-json-1.0.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/bower-json-1.0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/bower-json-1.0.0.1
hs-libraries: HSbower-json-1.0.0.1-EoWydgDtL842E9jXtX81Ro
depends:
    aeson-1.4.3.0-3wMMTmWfRNQF9dYXhjYZYB
    aeson-better-errors-0.9.1.0-KOfAXPhyxhv3T2HyQEHkgp base-4.12.0.0
    bytestring-0.10.8.2 deepseq-1.4.4.0 ghc-prim-0.5.3 mtl-2.2.2
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-9wTHYlaSuHyGA5dBBp2WV8
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-bower-json/html/bower-json.haddock
haddock-html: /usr/share/doc/haskell-bower-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bower-json-1.0.0.1-121-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bower-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bower-json
version: 1.0.0.1
id: bower-json-1.0.0.1-21xQqiK8EV3AhXhbWCZuUA
key: bower-json-1.0.0.1-21xQqiK8EV3AhXhbWCZuUA
license: MIT
maintainer: harry@garrood.me
author: Harry Garrood
homepage: https://github.com/hdgarrood/bower-json
synopsis: Read bower.json from Haskell
description:
    Bower is a package manager for the web (see <http://bower.io>).
    This package provides a data type and ToJSON/FromJSON instances for Bower'\''s
    package manifest file, bower.json.
category: Web
abi: d03cd9ce5162bb71c19a424461bd9eb4
exposed: True
exposed-modules:
    Web.Bower.PackageMeta
hidden-modules: Web.Bower.PackageMeta.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/bower-json-1.0.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/bower-json-1.0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/bower-json-1.0.0.1
hs-libraries: HSbower-json-1.0.0.1-21xQqiK8EV3AhXhbWCZuUA
depends:
    aeson-1.4.3.0-BTVTAPf4Xo575Po56SJ3Aq
    aeson-better-errors-0.9.1.0-4pVSzjuCEwd26shr3TRoCb base-4.12.0.0
    bytestring-0.10.8.2 deepseq-1.4.4.0 ghc-prim-0.5.3 mtl-2.2.2
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-2N7l4ZvxBr3HGayD0s0P1Q
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-bower-json/html/bower-json.haddock
haddock-html: /usr/share/doc/haskell-bower-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
